import React from "react";
import PropTypes from "prop-types";
import { styling } from "../Styling";

export interface ButtonProps {
  children: React.ReactNode;
  className?: string;
  color?: "blue" | "green" | "red";
  onClick: () => void;
}

const colors = {
  "blue": "bg-indigo-600 hover:bg-indigo-700 focus:ring-indigo-500",
  "green": "bg-green-600 hover:bg-green-700 focus:ring-green-500",
  "red": "bg-red-600 hover:bg-red-700 focus:ring-red-500"
};

export const Button = ({ children, className, color, onClick }: ButtonProps) => (
  <div
    className={[
      "flex justify-center py-2 px-4 rounded-md shadow-sm text-sm font-semibold text-white cursor-pointer focus:outline-none focus:ring-2 focus:ring-offset-2",
      colors[color],
      styling.button,
      className
    ].join(" ")}
    onClick={onClick}
  >
    {children}
  </div>
);

Button.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  color: PropTypes.oneOf(Object.keys(colors)),
  onClick: PropTypes.func.isRequired
};
Button.defaultProps = {
  color: "blue",
  onClick: () => null
};
