import React from "react";
import PropTypes from "prop-types";
import { styling } from "../Styling";
import { Button, ButtonProps } from "../Button";

export interface ButtonGroupProps {
  buttons: ButtonProps[];
  className?: string;
  color?: "blue" | "green" | "red";
}

const colors = {
  blue: "border-indigo-700",
  green: "border-green-700",
  red: "border-red-700"
};

export const ButtonGroup = ({ buttons, className, color }: ButtonGroupProps) => (
  <div className={[
    "flex flex-row",
    styling.buttonGroup,
      className
  ].join(" ")}>
    {buttons.map((button, idx) => (
      <Button
        {...button}
        color={button.color ?? color}
        className={[
          idx === 0 ? "" : "rounded-l-none",
          idx === buttons.length - 1 ? "" : "rounded-r-none border-r",
          colors[color],
          button.className
        ].join(" ")}
      />
    ))}
  </div>
);

ButtonGroup.propTypes = {
  buttons: PropTypes.array.isRequired,
  className: PropTypes.string,
  color: PropTypes.oneOf(Object.keys(colors))
};
ButtonGroup.defaultProps = {
  className: "",
  color: "blue"
};
